@@ -454,6 +454,35 @@ if (isset($_GET['validate_self_hosted'])) {
                        value="<?php if (!is_numeric($cookie_timeout_two_factor)) { echo '90'; } else { echo html_escape($cookie_timeout_two_factor); } ?>" />
             </div>
 
+            <div class="two_factor-divider">
+                <div style="margin: 20px 0; margin-top:40px;">
+                    <div style="padding:5px; text-align: start; font-weight: bold; font-size: 1.1em;"><?php echo _('OpenSearch and Logstash Log Folder'); ?></div>
+                    <hr style="border-color: #a5a5a5; margin: 5px 0;">
+                </div>
+            </div>
+            <div class="tw-mb-4">
+                <div class="ui-radio-group tw-flex tw-flex-col tw-gap-4">
+                    <div class="tw-flex tw-items-center tw-space-x-2">
+                        <input type="radio" id="log_location_default" name="log_location" value="default" <?php echo ($log_location == 'default') ? "checked" : ""; ?> class="ui-radio-group-item">
+                        <label for="log_location_default" class="ui-label">
+                            <?php echo _('Store logs inside the application directory'); ?>
+                            <p class="tw-text-[12.8px] tw-mt-1 tw-mb-2 tw-text-secondary-foreground/80 tw-mb-4">
+                                (e.g., /usr/local/nagioslogserver/{opensearch|logstash}/logs)
+                            </p>
+                        </label>
+                    </div>
+                    <div class="tw-flex tw-items-center tw-space-x-2">
+                        <input type="radio" id="log_location_var" name="log_location" value="var" <?php echo (!($log_location == 'default')) ? "checked" : ""; ?> class="ui-radio-group-item">
+                        <label for="log_location_var" class="ui-label">
+                            <?php echo _('Store logs in the system log directory'); ?>
+                            <p class="tw-text-[12.8px] tw-mt-1 tw-mb-2 tw-text-secondary-foreground/80 tw-mb-4">
+                                (e.g., /var/log/{opensearch|logstash})
+                            </p>
+                        </label>
+                    </div>
+                </div>
+            </div>
+
             <div class="tw-border-b tw-border-border tw-mt-2 tw-mb-4"></div>
 
             <!-- Experimental Features Section -->
