@@ -220,12 +220,12 @@
                                             <table class="ui-table">
                                                 <tbody class="ui-tbody">
                                                     <tr class="ui-tr">
-                                                        <td class="ui-td" style="width: 40%; min-width: 100px;"><?php echo _("Documents"); ?>:</td>
-                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['indices']['docs']['count']); ?></td>
+                                                        <td class="ui-td" style="width: 40%; min-width: 100px;"><?php echo _("Logs Stored On This Instance"); ?>:</td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['logstash_live_doc_count']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Documents Deleted"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['indices']['docs']['deleted']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['indices']['docs']['deleted']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Store Size"); ?>:</td>
@@ -233,31 +233,31 @@
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Index Total"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['indices']['indexing']['index_total']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['indices']['indexing']['index_total']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Delete Total"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['indices']['indexing']['delete_total']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['indices']['indexing']['delete_total']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Get Total"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['indices']['get']['total']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['indices']['get']['total']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Get(Exists) Total"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['indices']['get']['exists_total']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['indices']['get']['exists_total']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Get(Missing) Total"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['indices']['get']['missing_total']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['indices']['get']['missing_total']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Query Total"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['indices']['search']['query_total']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['indices']['search']['query_total']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Fetch Total"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['indices']['search']['fetch_total']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['indices']['search']['fetch_total']); ?></td>
                                                     </tr>
                                                 </tbody>
                                             </table>
@@ -275,11 +275,11 @@
                                                 <tbody class="ui-tbody">
                                                     <tr class="ui-tr">
                                                         <td class="ui-td" style="width: 40%; min-width: 100px;"><?php echo _("Open File Descriptors"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['process']['open_file_descriptors']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['process']['open_file_descriptors']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Maximum Open File Descriptors"); ?></td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['process']['max_file_descriptors']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['process']['max_file_descriptors']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("CPU Usage"); ?>:</td>
@@ -331,7 +331,7 @@
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("GC (Old) Count"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['jvm']['gc']['collectors']['old']['collection_count']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['jvm']['gc']['collectors']['old']['collection_count']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("GC (Old)Time"); ?>:</td>
@@ -339,7 +339,7 @@
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("GC (Young) Count"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $nodes['stats']['nodes'][$nodeid]['jvm']['gc']['collectors']['young']['collection_count']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($nodes['stats']['nodes'][$nodeid]['jvm']['gc']['collectors']['young']['collection_count']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("GC (Young)Time"); ?>:</td>
@@ -412,11 +412,11 @@
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Device Reads"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $device['read_operations']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($device['read_operations']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Device Writes"); ?>:</td>
-                                                        <td class="ui-td"><?php echo $device['write_operations']; ?></td>
+                                                        <td class="ui-td"><?php echo number_format($device['write_operations']); ?></td>
                                                     </tr>
                                                     <tr class="ui-tr">
                                                         <td class="ui-td"><?php echo _("Read Size"); ?>:</td>
