@@ -690,8 +690,8 @@
                 <?php } ?>
             </div>
             <div class="modal-footer">
-                <button type="button" id="remove-apply-now" class="btn btn-sm btn-success" <?php if (!$config_edit_allowed) { echo 'disabled'; } ?>><?php echo ($config_edit_allowed ? _('Apply Configuration Now') : _('You Cannot Apply Configuration')); ?></button>
-                <button type="button" id="remove-apply-later" class="btn btn-sm btn-default" aria-hidden="true"><?php echo _("Apply Later"); ?></button>
+                <button type="button" id="remove-apply-now" class="ui-btn ui-btn-default tw-mr-1" <?php if (!$config_edit_allowed) { echo 'disabled'; } ?>><?php echo ($config_edit_allowed ? _('Apply Configuration Now') : _('You Cannot Apply Configuration')); ?></button>
+                <button type="button" id="remove-apply-later" class="ui-btn ui-btn-outlined" data-dismiss="modal" aria-hidden="true"><?php echo _("Apply Later"); ?></button>
             </div>
         </div>
     </div>
@@ -962,6 +962,15 @@ $(document).ready(function() {
         // Send the new check to the API
         var url = site_url+'api/check/create/1';
         if (CURRENT_ACTION == 'edit') {
+            if (!validate_interval_string(check.check_interval) || !validate_interval_string(check.lookback_period)) {
+                check.message = '<?php echo _("You must enter a valid Check Interval and Lookback Period (valid suffixes include: s, m, h, d), w, m, and y."); ?>';
+                return check;
+            }
+            if (!validate_threshold_string(check.warning) || !validate_threshold_string(check.critical)) {
+                check.message = '<?php echo _("You must enter a valid Threshold."); ?>';
+                return check;
+            }
+
             url = site_url+'api/check/update';
             check.id = $('#a_id').val();
         }
@@ -1070,8 +1079,15 @@ function create_host_freshness_alert(check) {
     return check;
 }
 
-function create_query_based_alert(check) {
+function validate_interval_string(interval) {
+    return /^\d+[smhdwy]$/.test(interval);
+}
 
+function validate_threshold_string(threshold) {
+    return /^\d+$/.test(threshold);
+}
+
+function create_query_based_alert(check) {
     var aco = 0;
     if ($('#a_send_wc_only').is(":checked")) {
         aco = 1;
@@ -1090,11 +1106,12 @@ function create_query_based_alert(check) {
     }
 
     // Verify interval and loopback period
-    var ci = check.check_interval;
-    var lp = check.lookback_period;
-    var valid_time = ['s', 'm', 'h', 'd', 'w', 'm', 'y'];
-    if (valid_time.indexOf(ci.substr(-1)) == -1 || valid_time.indexOf(lp.substr(-1)) == -1) {
-        check.message = '<?php echo _("You must enter a valid time. (Valid suffexes: s, m, h, d)"); ?>';
+    if (!validate_interval_string(check.check_interval) || !validate_interval_string(check.lookback_period)) {
+        check.message = '<?php echo _("You must enter a valid Check Interval and Lookback Period (valid suffixes include: s, m, h, d, w, and y.)"); ?>';
+        return check;
+    }
+    if (!validate_threshold_string(check.warning) || !validate_threshold_string(check.critical)) {
+        check.message = '<?php echo _("You must enter a valid Threshold."); ?>';
         return check;
     }
 
